@@ -10,7 +10,7 @@ import inspect
 from dslibrary.engine_intf import FileSystem
 from dslibrary.front import DSLibraryException
 from dslibrary.metadata import Metadata
-from dslibrary.utils.file_utils import write_stream_with_read_on_close
+from dslibrary.utils.file_utils import write_stream_with_read_on_close, FileOpener
 from dslibrary import DSLibrary
 
 try:
@@ -76,6 +76,9 @@ class DSLibraryViaMMLibrary(DSLibrary):
         # these patterns indicate obviously local files
         if path.startswith("./") or path.startswith("/"):
             return open(path, mode)
+        # obvious URL of external source
+        if "://" in path:
+            return FileOpener().open(path, mode, **kwargs)
         # we write to a temporary file, then send the file on close
         if 'w' in mode:
             writer = self._find_method("save_binary_to_resource", "saveBinaryToResource")
