@@ -13,6 +13,37 @@ FileFormatDescription = namedtuple("FileFormatDescription", "format read_args si
 PTN_NOT_HEADER = re.compile(r'^([-+]?\s*(\d+(\.\d*)?|\.\d+)([eE][-+]?\d+)?)?$')
 # a likely looking single-column CSV file - first line contains a non-delimited string-like value
 PTN_SINGLE_COL_CSV = re.compile(r'^(?!([0-9]|\.[0-9]|{|\[))' + r'[^\s,;|:]+[ \t]*\n.*')
+PTN_SINGLE_COL_CSV_B = re.compile(rb'^(?!([0-9]|\.[0-9]|{|\[))' + rb'[^\s,;|:]+[ \t]*\n.*')
+
+VALID_CSV_OPTIONS = frozenset({
+    "sep", "delimiter", "header", "names", "usecols", "prefix", "mangle_dupe_cols", "dtype", "true_values",
+    "false_values", "skipinitialspace", "skiprows", "skipfooter", "na_values", "keep_default_na",
+    "na_filter", "skip_blank_lines", "parse_dates", "infer_datetime_format", "keep_date_col", "dayfirst",
+    "cache_dates", "compression", "thousands", "decimal", "lineterminator", "quotechar", "quoting",
+    "doublequote", "escapechar", "comment", "encoding", "delim_whitespace", "float_precision", "nrows",
+    "chunksize",
+})
+VALID_JSON_OPTIONS = frozenset({
+    "orient", "dtype", "convert_dates", "keep_default_dates", "precise_float", "date_unit", "encoding",
+    "compression", "lines", "nrows", "chunksize",
+})
+VALID_HDF_OPTIONS = frozenset({
+    "key", "errors", "start", "stop", "chunksize",
+})
+VALID_EXCEL_OPTIONS = frozenset({
+    "sheet_name", "header", "names", "index_col", "usecols", "squeeze", "dtype", "engine", "true_values",
+    "false_values", "skiprows", "nrows", "na_values", "keep_default_na",
+    "parse_dates", "thousands", "comment", "skipfooter", "convert_float", "mangle_dupe_cols"
+})
+VALID_PARQUET_OPTIONS = frozenset({
+    "engine", "columns", "use_nullable_dtypes",
+})
+VALID_OPTIONS = {
+    "csv": VALID_CSV_OPTIONS,
+    "json": VALID_JSON_OPTIONS,
+    "hdf": VALID_HDF_OPTIONS,
+    "xlsx": VALID_EXCEL_OPTIONS
+}
 
 
 def detect_format(
@@ -26,7 +57,7 @@ def detect_format(
     :param filename:        Name or URL for file, used specifically and only to guess format from extension.
     :param sampler:         A method that returns a sample, a sample, or None.
     :param sizer:           A method that returns the file's size, the size, or None.
-    :param supplied_options:    Caller-supplied formatting options which will override the detection process.
+    :param supplied_options:  Caller-supplied formatting options which will override the detection process.
     :param fallback_to_text:  True to assume any unrecognized format that looks like a text file should be read line by line.
 
     :returns:  A FileFormatDescription, with fields:
@@ -65,6 +96,8 @@ def detect_format(
             format = "json"
         elif not format and looks_like_csv(sample):
             format = "csv"
+        elif not format and looks_like_hdf(sample):
+            format = "hdf"
         if format == "csv":
             apply_csv_read_args(sample, read_args)
         elif format == "json":
@@ -80,9 +113,22 @@ def detect_format(
         avg_line_size = average_line_size(sample)
     # override determined options with supplied values
     if supplied_options:
+        # user can supply chunksize in bytes, we will convert it to lines
+        chunksize_bytes = supplied_options.pop("chunksize_bytes", None)
+        if chunksize_bytes and avg_line_size:
+            supplied_options["chunksize"] = max(chunksize_bytes // avg_line_size, 1)
+        # FIXME it seems very dangerous to mix supplied and detected options
+        #  1) add a 'nosniff' option
+        #  2) work through likely cases where we would want to inhibit sniffed options because of a user-provided option
         overrides = dict(supplied_options)
         overrides.pop("format", None)
         read_args.update(overrides)
+    # limit to valid options for format
+    if format in VALID_OPTIONS:
+        valid_opts = VALID_OPTIONS[format]
+        invalid = set(read_args) - valid_opts
+        if invalid:
+            raise ValueError(f"Invalid options for format={format}: {', '.join(invalid)}")
     # return final synopsis
     return FileFormatDescription(format, read_args, size, avg_line_size)
 
@@ -122,14 +168,16 @@ def looks_like_csv(sample):
     """
     if not sample:
         return
-    if not isinstance(sample, str):
-        try:
-            sample = sample.decode("utf-8")
-        except UnicodeDecodeError:
-            # non-unicode >> assume not CSV
-            return
-    lines = sample.split("\n")[:10]
-    for splitter, sep, threshold in ((re.compile(r"\t"), "\t", 2), (re.compile(r","), ",", 2), (re.compile(r"\s+"), "\\s+", 3)):
+    if isinstance(sample, str):
+        eol = "\n"
+        DELIMS = ((re.compile(r"\t"), "\t", 2), (re.compile(r","), ",", 2), (re.compile(r"\s+"), "\\s+", 3))
+        ptn_single = PTN_SINGLE_COL_CSV
+    else:
+        eol = b"\n"
+        DELIMS = ((re.compile(rb"\t"), "\t", 2), (re.compile(rb","), ",", 2), (re.compile(rb"\s+"), "\\s+", 3))
+        ptn_single = PTN_SINGLE_COL_CSV_B
+    lines = sample.split(eol)[:10]
+    for splitter, sep, threshold in DELIMS:
         n_cols = []
         for line in lines:
             if line:
@@ -137,9 +185,10 @@ def looks_like_csv(sample):
         if min(n_cols) != max(n_cols) or n_cols[0] < threshold:
             continue
         return sep
-    if PTN_SINGLE_COL_CSV.match(sample):
+    if ptn_single.match(sample):
         return "\n"
 
+
 def looks_like_json(sample, size: int=None):
     """
     Detect fairly obvious JSON format.
@@ -168,6 +217,16 @@ def looks_like_json(sample, size: int=None):
     return True
 
 
+def looks_like_hdf(sample):
+    """
+    HDF files always start with a specific byte sequence.
+    """
+    header = b'\x89\x48\x44\x46\x0d\x0a'
+    if isinstance(sample, str):
+        sample = sample.encode("utf-8", errors='ignore')
+    return sample.startswith(header)
+
+
 def looks_like_text_file(sample):
     """
     Detect a text file, i.e. any kind of file that is not binary.  Such files can be considered, as a fallback, to
